==> react-ui-library-0.7.20.tgz: package/src/components/NavigationBar.js <==
import React, { PropTypes } from 'react'
import { css } from 'glamor'
import Pane from './Pane'
import Text from './Text'
import Link from './Link'
import Box from './Box'
import SegmentLogo from './SegmentLogo'
import theme from './theme'

const NavigationBarLink = (props) => <Link primary={false} {...css({
  color: theme.rawColors.blue100,
  '&:hover': {
    color: 'white',
    backgroundColor: theme.rawColors.blue800
  },
  '&:active, &.active': {
    color: 'white',
    backgroundColor: theme.rawColors.blue500
  }
})} {...props} />

NavigationBarLink.defaultProps = {
  circle: true,
  paddingX: 3,
  paddingY: 1,
  marginX: 1
}

const NavigationBarTitle = props => <Text {...props} />

NavigationBarTitle.defaultProps = {
  is: 'h1',
  textStyle: 'display3',
  bold: true
}

// paddingTop is somewhat of a hack here, but flex will cause the truncate to fail
const NavigationBarLeftTitle = ({ children, ...props }) =>
  <Box marginLeft truncate paddingTop='3px' paddingLeft borderLeft borderColor='rgba(255,255,255,0.2)'>
    <Text is='span' textStyle='body1' {...props}>{children}</Text>
  </Box>


const NavigationBarLogo = props =>
  <SegmentLogo marginTop='-1px' minWidth='106px' width='106px' {...props} />

const NavigationBarPane = props =>
  <Pane alignItems='center' dark display='flex' {...props} />

const NavigationBar = ({ logo, left, right, height, children, ...props }) => {
  let child
  if (typeof children === 'string') {
    child = <NavigationBarTitle>{children}</NavigationBarTitle>
  } else {
    child = children
  }

  let leftChild
  if (typeof left === 'string') {
    leftChild = <NavigationBarLeftTitle>{left}</NavigationBarLeftTitle>
  } else {
    leftChild = left
  }

  return (
    <NavigationBarPane height={height} {...props}>
      <Pane width={4} height='100%' padding={4} display='flex'>{logo} {leftChild}</Pane>
      <Pane flexAuto textAlign='center'>{child}</Pane>
      <Pane width={4} textAlign='right' padding={3}>{right}</Pane>
    </NavigationBarPane>
  )
}

NavigationBar.propTypes = {
  logo: PropTypes.node,
  left: PropTypes.node,
  right: PropTypes.node,
  children: PropTypes.oneOfType([
    PropTypes.node,
    PropTypes.string
  ]),
  height: PropTypes.string
}

NavigationBar.defaultProps = {
  logo: <NavigationBarLogo />,
  height: '56px'
}

export {
  NavigationBar,
  NavigationBarLink,
  NavigationBarTitle
}

==> react-ui-library-1.0.0.tgz: package/src/components/NavigationBar.js <==
import React, { PropTypes } from 'react'
import { css } from 'glamor'
import Pane from './Pane'
import Text from './Text'
import Link from './Link'
import Box from './Box'
import SegmentLogo from './SegmentLogo'
import theme from './theme'
const { minorScale, majorScale  } = theme

const NavigationBarLink = (props) => <Link primary={false} {...css({
  color: theme.rawColors.blue100,
  '&:hover': {
    color: 'white',
    backgroundColor: theme.rawColors.blue800
  },
  '&:active, &.active': {
    color: 'white',
    backgroundColor: theme.rawColors.blue500
  }
})} {...props} />

NavigationBarLink.defaultProps = {
  circle: true,
  paddingX: minorScale(3),
  paddingY: minorScale(1),
  marginX: minorScale(1)
}

const NavigationBarTitle = props => <Text {...props} />

NavigationBarTitle.defaultProps = {
  is: 'h1',
  textStyle: 'display3',
  bold: true
}

// paddingTop is somewhat of a hack here, but flex will cause the truncate to fail
const NavigationBarLeftTitle = ({ children, ...props }) =>
  <Box marginLeft={majorScale(2)} truncate paddingTop='1px' paddingLeft={majorScale(2)} borderLeft borderColor='rgba(255,255,255,0.2)'>
    <Text is='span' textStyle='body1' {...props}>{children}</Text>
  </Box>

const NavigationBarLogo = props =>
  <SegmentLogo marginTop='-1px' minWidth='106px' width='106px' {...props} />

const NavigationBarPane = props =>
  <Pane alignItems='center' dark display='flex' {...props} />

const NavigationBar = ({ logo, left, right, height, children, ...props }) => {
  let child
  if (typeof children === 'string') {
    child = <NavigationBarTitle>{children}</NavigationBarTitle>
  } else {
    child = children
  }

  let leftChild
  if (typeof left === 'string') {
    leftChild = <NavigationBarLeftTitle>{left}</NavigationBarLeftTitle>
  } else {
    leftChild = left
  }

  return (
    <NavigationBarPane height={height} {...props}>
      <Pane width='33%' height='100%' padding={majorScale(2)} display='flex'>{logo} {leftChild}</Pane>
      <Pane flexAuto textAlign='center'>{child}</Pane>
      <Pane width='33%' textAlign='right' padding={minorScale(3)}>{right}</Pane>
    </NavigationBarPane>
  )
}

NavigationBar.propTypes = {
  logo: PropTypes.node,
  left: PropTypes.node,
  right: PropTypes.node,
  children: PropTypes.oneOfType([
    PropTypes.node,
    PropTypes.string
  ]),
  height: PropTypes.string
}

NavigationBar.defaultProps = {
  logo: <NavigationBarLogo />,
  height: majorScale(7)
}

export {
  NavigationBar,
  NavigationBarLink,
  NavigationBarTitle
}
